@@ -1,9 +1,14 @@
+from typing import Optional
+
+
 class OAuth2Error(Exception):
     pass
 
 
 class TokenResponseError(OAuth2Error):
-    def __init__(self, error, description, uri):
+    def __init__(
+        self, error: str, description: Optional[str] = None, uri: Optional[str] = None
+    ):
         self.error = error
         self.description = description
         self.uri = uri
@@ -13,6 +18,10 @@ class InvalidTokenResponse(OAuth2Error):
     pass
 
 
+class ExpiredToken(OAuth2Error):
+    pass
+
+
 class UnknownTokenResponseError(TokenResponseError):
     pass
 
@@ -41,5 +50,21 @@ class UnauthorizedClient(TokenResponseError):
     pass
 
 
-class ExpiredToken(OAuth2Error):
+class DeviceAuthorizationError(TokenResponseError):
+    pass
+
+
+class AuthorizationPending(DeviceAuthorizationError):
+    pass
+
+
+class SlowDown(DeviceAuthorizationError):
+    pass
+
+
+class ExpiredDeviceCode(DeviceAuthorizationError):
+    pass
+
+
+class InvalidDeviceAuthorizationResponse(OAuth2Error):
     pass
